.. _using-index:

############
Installation
############


This part of the documentation is devoted to general information on the setup
and configuration of BigJob and things that make working with BigJob easier.


.. toctree::

   install.rst
   redis.rst
   xsede.rst
   trouble.rst
